@@ -2,19 +2,19 @@ require 'spec_helper_acceptance'
 
 describe 'concat backup parameter' do
   basedir = default.tmpdir('concat')
-  context '=> puppet' do
+  context 'when puppet' do
     before(:all) do
-      pp = <<-EOS
+      pp = <<-MANIFEST
         file { '#{basedir}':
           ensure => directory,
         }
         file { '#{basedir}/file':
           content => "old contents\n",
         }
-      EOS
+      MANIFEST
       apply_manifest(pp)
     end
-    pp = <<-EOS
+    pp = <<-MANIFEST
       concat { '#{basedir}/file':
         backup => 'puppet',
       }
@@ -22,34 +22,34 @@ describe 'concat backup parameter' do
         target  => '#{basedir}/file',
         content => 'new contents',
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest twice with "Filebucketed" stdout and no stderr' do
-      apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/Filebucketed #{basedir}\/file to puppet with sum 0140c31db86293a1a1e080ce9b91305f/)
+      apply_manifest(pp, catch_failures: true) do |r|
+        expect(r.stdout).to match(%r{Filebucketed #{basedir}/file to puppet with sum 0140c31db86293a1a1e080ce9b91305f})
       end
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{basedir}/file") do
-      it { should be_file }
-      its(:content) { should match /new contents/ }
+      it { is_expected.to be_file }
+      its(:content) { is_expected.to match %r{new contents} }
     end
   end
 
-  context '=> .backup' do
+  context 'when .backup' do
     before(:all) do
-      pp = <<-EOS
+      pp = <<-MANIFEST
         file { '#{basedir}':
           ensure => directory,
         }
         file { '#{basedir}/file':
           content => "old contents\n",
         }
-      EOS
+      MANIFEST
       apply_manifest(pp)
     end
-    pp = <<-EOS
+    pp = <<-MANIFEST
       concat { '#{basedir}/file':
         backup => '.backup',
       }
@@ -57,40 +57,40 @@ describe 'concat backup parameter' do
         target  => '#{basedir}/file',
         content => 'new contents',
       }
-    EOS
+    MANIFEST
 
     # XXX Puppet doesn't mention anything about filebucketing with a given
     # extension like .backup
     it 'applies the manifest twice  no stderr' do
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{basedir}/file") do
-      it { should be_file }
-      its(:content) { should match /new contents/ }
+      it { is_expected.to be_file }
+      its(:content) { is_expected.to match %r{new contents} }
     end
     describe file("#{basedir}/file.backup") do
-      it { should be_file }
-      its(:content) { should match /old contents/ }
+      it { is_expected.to be_file }
+      its(:content) { is_expected.to match %r{old contents} }
     end
   end
 
   # XXX The backup parameter uses validate_string() and thus can't be the
   # boolean false value, but the string 'false' has the same effect in Puppet 3
-  context "=> 'false'" do
+  context "when 'false'" do
     before(:all) do
-      pp = <<-EOS
+      pp = <<-MANIFEST
         file { '#{basedir}':
           ensure => directory,
         }
         file { '#{basedir}/file':
           content => "old contents\n",
         }
-      EOS
+      MANIFEST
       apply_manifest(pp)
     end
-    pp = <<-EOS
+    pp = <<-MANIFEST
       concat { '#{basedir}/file':
         backup => '.backup',
       }
@@ -98,18 +98,18 @@ describe 'concat backup parameter' do
         target  => '#{basedir}/file',
         content => 'new contents',
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest twice with no "Filebucketed" stdout and no stderr' do
-      apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to_not match(/Filebucketed/)
+      apply_manifest(pp, catch_failures: true) do |r|
+        expect(r.stdout).not_to match(%r{Filebucketed})
       end
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{basedir}/file") do
-      it { should be_file }
-      its(:content) { should match /new contents/ }
+      it { is_expected.to be_file }
+      its(:content) { is_expected.to match %r{new contents} }
     end
   end
 end
