@@ -1,24 +1,24 @@
 require 'spec_helper_acceptance'
 
 case fact('osfamily')
-  when 'AIX'
-    username = 'root'
-    groupname = 'system'
-  when 'Darwin'
-    username = 'root'
-    groupname = 'wheel'
-  when 'windows'
-    username = 'Administrator'
-    groupname = 'Administrators'
-  else
-    username = 'root'
-    groupname = 'root'
+when 'AIX'
+  username = 'root'
+  groupname = 'system'
+when 'Darwin'
+  username = 'root'
+  groupname = 'wheel'
+when 'windows'
+  username = 'Administrator'
+  groupname = 'Administrators'
+else
+  username = 'root'
+  groupname = 'root'
 end
 
 describe 'concat::fragment source' do
   basedir = default.tmpdir('concat')
-  context 'should read file fragments from local system' do
-    pp = <<-EOS
+  context 'when run should read file fragments from local system' do
+    pp = <<-MANIFEST
       file { '#{basedir}/file1':
         content => "file1 contents\n"
       }
@@ -41,25 +41,33 @@ describe 'concat::fragment source' do
         source  => '#{basedir}/file2',
         require => File['#{basedir}/file2'],
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest twice with no stderr' do
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{basedir}/foo") do
-      it { should be_file }
-      its(:content) {
-        should match 'file1 contents'
-        should match 'string1 contents'
-        should match 'file2 contents'
-      }
-    end
-  end # should read file fragments from local system
+      it { is_expected.to be_file }
 
-  context 'should create files containing first match only.' do
-    pp = <<-EOS
+      its(:content) do
+        is_expected.to match 'file1 contents'
+      end
+
+      its(:content) do
+        is_expected.to match 'string1 contents'
+      end
+
+      its(:content) do
+        is_expected.to match 'file2 contents'
+      end
+    end
+  end
+  # should read file fragments from local system
+
+  context 'when run should create files containing first match only.' do
+    pp = <<-MANIFEST
       file { '#{basedir}/file1':
         content => "file1 contents\n"
       }
@@ -100,37 +108,43 @@ describe 'concat::fragment source' do
         require => [ File['#{basedir}/file1'], File['#{basedir}/file2'] ],
         order   => '01',
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest twice with no stderr' do
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
     describe file("#{basedir}/result_file1") do
-      it { should be_file }
-      its(:content) {
-        should match 'file1 contents'
-        should_not match 'file2 contents'
-      }
+      it { is_expected.to be_file }
+      its(:content) do
+        is_expected.to match 'file1 contents'
+      end
+      its(:content) do
+        is_expected.not_to match 'file2 contents'
+      end
     end
     describe file("#{basedir}/result_file2") do
-      it { should be_file }
-      its(:content) {
-        should match 'file2 contents'
-        should_not match 'file1 contents'
-      }
+      it { is_expected.to be_file }
+      its(:content) do
+        is_expected.to match 'file2 contents'
+      end
+      its(:content) do
+        is_expected.not_to match 'file1 contents'
+      end
     end
     describe file("#{basedir}/result_file3") do
-      it { should be_file }
-      its(:content) {
-        should match 'file1 contents'
-        should_not match 'file2 contents'
-      }
+      it { is_expected.to be_file }
+      its(:content) do
+        is_expected.to match 'file1 contents'
+      end
+      its(:content) do
+        is_expected.not_to match 'file2 contents'
+      end
     end
   end
 
-  context 'should fail if no match on source.' do
-    pp = <<-EOS
+  context 'when run should fail if no match on source.' do
+    pp = <<-MANIFEST
       concat { '#{basedir}/fail_no_source':
         owner   => '#{username}',
         group   => '#{groupname}',
@@ -142,15 +156,14 @@ describe 'concat::fragment source' do
         source => [ '#{basedir}/nofilehere', '#{basedir}/nothereeither' ],
         order   => '01',
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest with resource failures' do
-      expect(apply_manifest(pp, :catch_failures => true).stderr).to match(/Failed to generate additional resources using 'eval_generate'/)
+      expect(apply_manifest(pp, catch_failures: true).stderr).to match(%r{Failed to generate additional resources using 'eval_generate'})
     end
     describe file("#{basedir}/fail_no_source") do
-      #FIXME: Serverspec::Type::File doesn't support exists? for some reason. so... hack.
-      it { should_not be_directory }
+      # FIXME: Serverspec::Type::File doesn't support exists? for some reason. so... hack.
+      it { is_expected.not_to be_directory }
     end
   end
 end
-
