@@ -4,19 +4,19 @@ describe 'quoted paths' do
   basedir = default.tmpdir('concat')
 
   before(:all) do
-    pp = <<-EOS
+    pp = <<-MANIFEST
       file { '#{basedir}':
         ensure => directory,
       }
       file { '#{basedir}/concat test':
         ensure => directory,
       }
-    EOS
+    MANIFEST
     apply_manifest(pp)
   end
 
-  context 'path with blanks' do
-    pp = <<-EOS
+  context 'with path with blanks' do
+    pp = <<-MANIFEST
       concat { '#{basedir}/concat test/foo':
       }
       concat::fragment { '1':
@@ -27,16 +27,16 @@ describe 'quoted paths' do
         target  => '#{basedir}/concat test/foo',
         content => 'string2',
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest twice with no stderr' do
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{basedir}/concat test/foo") do
-      it { should be_file }
-      its(:content) { should match /string1string2/ }
+      it { is_expected.to be_file }
+      its(:content) { is_expected.to match %r{string1string2} }
     end
   end
 end
