@@ -2,7 +2,7 @@ require 'spec_helper_acceptance'
 
 describe 'symbolic name' do
   basedir = default.tmpdir('concat')
-  pp = <<-EOS
+  pp = <<-MANIFEST
     concat { 'not_abs_path':
       path => '#{basedir}/file',
     }
@@ -18,16 +18,20 @@ describe 'symbolic name' do
       content => '2',
       order   => '02',
     }
-  EOS
+  MANIFEST
 
   it 'applies the manifest twice with no stderr' do
-    apply_manifest(pp, :catch_failures => true)
-    apply_manifest(pp, :catch_changes => true)
+    apply_manifest(pp, catch_failures: true)
+    apply_manifest(pp, catch_changes: true)
   end
 
   describe file("#{basedir}/file") do
-    it { should be_file }
-    it { should contain '1' }
-    it { should contain '2' }
+    it { is_expected.to be_file }
+    its(:content) do
+      is_expected.to match '1'
+    end
+    its(:content) do
+      is_expected.to match '2'
+    end
   end
 end
